@@ -4,7 +4,7 @@ from InterfaceBuilderKit import *
 
 class TestIBInspector (TestCase):
     def testMethods(self):
-        self.failUnlessResultIsBOOL(IBInspector.supportsMultipleObjectInspection)
+        self.assertResultIsBOOL(IBInspector.supportsMultipleObjectInspection)
 
 if __name__ == "__main__":
     main()
